# <img src="https://dagshub.com/DataHack/DataHack-Resources-2019/raw/master/datahacklogo.png" width="40">  DataHack Resources 2019

This is a list of resources for DataHack, and includes link to repositories and guides for machine learning and data science. Want to join DataHack 2019? Go to https://registration.datahack.org.il

**Have any suggestions? Pull requests are very welcome.**
## Table of Contents
1. [List of Challenges](#list-of-challenges-)
1. [The Basics](#the-basics-)
3. [IBM Cloud Resources](#ibm-cloud-resources-)
4. [General Resources](#general-resources-)
3. [Vision & Image](#vision--image---)
4. [NLP](#nlp-)
5. [Voice & Audio](#voice--audio-)
6. [Tabular Data](#tabular-data-)

## List of Challenges 🏆
* [Orcam](https://www.datahack.org.il/challenge/orcam-faceless-recognition)
  * [Leaderboard] (https://leaderboard.datahack.org.il/orcam)
* [Armis](https://www.datahack.org.il/challenge/armis-devices-gone-rogue)
  * [Leaderboard] (https://leaderboard.datahack.org.il/armis)
* [Lightricks](https://www.datahack.org.il/challenge/lightricks-data-driven-art)
* [Monday (DataLearn)](https://www.datahack.org.il/challenge/lightricks-data-driven-art)
  * [Leaderboard] (https://leaderboard.datahack.org.il/monday)

If you're working on one of these challenges, be sure to check out the [leaderboard instructions](Leaderboard.md).

## The Basics 🛠️
* [Pandas](https://pandas.pydata.org) - pandas is an open source, BSD-licensed library providing high-performance, easy-to-use data structures and data analysis tools for the Python programming language.
* [Numpy](https://www.numpy.org) - NumPy is the fundamental package for scientific computing with Python. It contains among other things:
    * a powerful N-dimensional array object
    * sophisticated (broadcasting) functions
    * tools for integrating C/C++ and Fortran code
    * useful linear algebra, Fourier transform, and random number capabilities
* [Scikit-Learn](https://scikit-learn.org/stable/) - Machine Learning in Python
    * Simple and efficient tools for data mining and data analysis
    * Accessible to everybody, and reusable in various contexts
    * Built on NumPy, SciPy, and matplotlib
* [TensorFlow](https://www.tensorflow.org) - Google's machine learning (and deep learning) framework
* [PyTorch](https://pytorch.org) - Facebook's machine learning framework - Tensors and Dynamic neural networks in Python with strong GPU acceleration.

## IBM Cloud Resources <img src="https://upload.wikimedia.org/wikipedia/en/0/00/IBM_Watson_Logo_2017.png" width=40 />
Specially for DataHackers IBM offers a __6-month promo code worth $1,200 USD__ in IBM Cloud services including:
* Data analysis with Jupyter notebooks or RStudio 
* Dashboards of data visualization without coding 
* Object storage to upload your data
* Streaming data analysis 
* Data Refinery to cleanse and shape data 
* Free data sets from IBM Watson Community

How to start:
1. Register to IBM Cloud and redeem your $1,200 promo code following the link: 
https://drive.google.com/file/d/1aZ1jYKX-O8-LmBqaUoN6Xu2g8DE5kYkn/view?usp=sharing
1. Instructions on how to get started, including how to upload data to the notebook: https://drive.google.com/open?id=1bGQDijjJX2tiUBQ410e4AAMupfISTkjq
2. Short video tutorials to learn how to use the tools 
  * https://www.youtube.com/watch?v=rSHDsCTl_c0
  * https://dataplatform.cloud.ibm.com/docs/content/wsj/getting-started/videos.html?audience=wdp&context=wdp

__There are limited promo codes, so take advantage of this free offer before it’s gone.__

## General Resources 🤖
### Blog Posts 
* [A Recipe for Training Neural Networks](http://karpathy.github.io/2019/04/25/recipe/) / Andrej Karpathy - Talks about common errors in training neural networks and how to avoid them.

### Awesome Lists
* [DataHack Projects](https://github.com/DataHackIL/DataProjects) - A list of DataHack projects from previous years.
* [DataHack Workshops](https://github.com/DataHackIL/DataWorkshops) - A list of workshops given in previous DataHack events.
* [DataHack Challenges](https://github.com/DataHackIL/DataChallenges) - A list of challenges given in previous DataHack events.
* [Awesome List of Deep Learning Project Ideas](https://github.com/NirantK/awesome-project-ideas) - Curated list of Machine Learning, NLP, Vision, Recommender Systems Project Ideas. **Includes datasets**
* [Awesome Data Science](https://github.com/bulutyazilim/awesome-datascience) - A repository to learn and apply data science in real world problems 
* [Awesome Data Visualizations](https://github.com/fasouto/awesome-dataviz)
* [Awesome Machine Learning](https://github.com/josephmisiti/awesome-machine-learning)

### Repositories
* [Tensor2Tensor](https://github.com/tensorflow/tensor2tensor) GitHub repository - A library of deep learning models and datasets designed to make deep learning more accessible and accelerate ML research
* [HungaBunga](https://github.com/ypeleg/HungaBunga) By the one and only Yam Peleg, a brute-force AutoML package which just throws everything in Scikit-Learn at your data to see what sticks. May or may not blow up your machine.

### Datasets
* [DataHack Open Datasets](https://github.com/DataHackIL/DataSets) - A list of cool open source datasets.


### Experiment Tracking
* [Tensorboard](https://www.tensorflow.org/tensorboard)
  * [How to run Tensorboard in notebooks](https://colab.research.google.com/github/tensorflow/tensorboard/blob/master/docs/r2/tensorboard_in_notebooks.ipynb)
  * [Using Tensorboard with Pytorch](https://pytorch.org/docs/stable/tensorboard.html)
* [MLFlow](https://mlflow.org/)
* [Sacred](https://github.com/IDSIA/sacred/)
* [Trains](https://github.com/allegroai/trains/)
* [<img src="https://dagshub.com/img/favicon.svg" width=40 /> DAGsHub](https://dagshub.com/docs/overview/)

## Vision & Image 👁️ + 🖼️
### Awesome Lists
* [Awesome Vision](https://github.com/jbhuang0604/awesome-computer-vision) - A curated list of awesome computer vision resources
* [Awesome GAN Applications](https://github.com/nashory/gans-awesome-applications)
* [CycleGAN & Pix2Pix](https://github.com/junyanz/pytorch-CycleGAN-and-pix2pix) - Image-to-Image Translation in PyTorch. Software that can generate photos from paintings, turn horses into zebras, perform style transfer

### Datasets
* http://www.cvpapers.com/datasets.html
* https://www.visualdata.io

## NLP 💬
### Awesome Lists
* [Awesome NLP](https://github.com/keon/awesome-nlp) - 📖 A curated list of resources dedicated to Natural Language Processing (NLP)

### Repositories
* [Fairseq](https://github.com/pytorch/fairseq) - A sequence modeling toolkit enabling training custom models for translation, summarization, language modeling and other text generation tasks. It provides reference implementations of various sequence-to-sequence models
* [OpenAI GPT-2](https://github.com/openai/gpt-2) - A really good pretrained language model (Code for the paper "Language Models are Unsupervised Multitask Learners")

### Datasets
* https://github.com/niderhoff/nlp-datasets 

## Voice & Audio 📣
### Awesome Lists
* [Awesome Deep Learning Music](https://github.com/ybayle/awesome-deep-learning-music) - Most links don't have code
* [Awesome Audio Visualizations](https://github.com/willianjusten/awesome-audio-visualization)
* [Awesome Speech Recognition and Speech Synthesis **Papers**](https://github.com/zzw922cn/awesome-speech-recognition-speech-synthesis-papers) - Note that these are academic papers

## Tabular Data 📊
### Blog Posts
* [An Introduction to Deep Learning for Tabular Data](https://www.fast.ai/2018/04/29/categorical-embeddings/) - By Fast.ai

### Repositories
* [XGBoost](https://github.com/dmlc/xgboost) - Scalable, Portable and Distributed Gradient Boosting (GBDT, GBRT or GBM) Library, for Python, R, Java, Scala, C++ and more. Runs on single machine, Hadoop, Spark, Flink and DataFlow


